//
//  RootViewController.swift
//  MadLibs
//
//

import Cocoa

class RootViewController: NSViewController {
    @IBOutlet weak var pastTenseVerbTextField: NSTextField!

    @IBOutlet weak var singularNounCombo: NSComboBox!
    var singularNouns: Array <String>!
    
    @IBOutlet weak var pluralNounPopup: NSPopUpButton!
    var pluralNouns: Array <String>!
    
    @IBOutlet var phraseTextView: NSTextView!
    @IBOutlet weak var amountLabel: NSTextField!
    @IBOutlet weak var amountSlider: NSSlider!
    @IBOutlet weak var datePicker: NSDatePicker!
    @IBOutlet weak var placeRadioButton: NSMatrix!
    @IBOutlet weak var yellCheck: NSButton!
    @IBOutlet weak var resultTextField: NSTextField!
    @IBOutlet weak var imageView: NSImageView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do view setup here.
    }
    
    override func awakeFromNib() {
        // Set the default text for the pastTenseVerbTextField property
        pastTenseVerbTextField.stringValue = "ate"
        
        // Setup the combo box with singular nouns
        singularNouns = ["dog", "muppet", "ninja", "fat dude"]
        singularNounCombo.removeAllItems()
        singularNounCombo.addItemsWithObjectValues(singularNouns)
        singularNounCombo.selectItemAtIndex(2)
        
        // Setup the pop up button with plural nouns
        pluralNouns = ["tacos", "rainbows", "iPhones", "gold coins"]
        pluralNounPopup.removeAllItems()
        pluralNounPopup.addItemsWithTitles(pluralNouns)
        pluralNounPopup.selectItemAtIndex(0)
        
        // Setup the default text to display in the text view
        phraseTextView.string = "Me coding Mac Apps!!!"
        
        // Update the amount slider
        sliderChanged(self)
        
        // Set the date picker to display the current date
        datePicker.dateValue = NSDate()
        
        // Set the radio group's initial selection
        placeRadioButton.selectCellAtRow(2, column: 0)
        
        // set check button state
        yellCheck.state = NSOffState
    }
    
    @IBAction func sliderChanged(sender: AnyObject) {
        let amount = amountSlider.integerValue
        amountLabel.stringValue = "Amount: [\(amount)]"
    }
    
    @IBAction func goButton(sender: AnyObject) {
        // Past tense verb
        let pastTenseVerb = pastTenseVerbTextField.stringValue
        
        // Singular noun
        let singularNoun = singularNounCombo.stringValue
        
        // Place
        let cell: NSButtonCell = placeRadioButton.selectedCell() as! NSButtonCell
        let placeString = cell.title
        
        // Amount
        let amount = amountSlider.integerValue
        
        // Plural noun
        let pluralNoun = pluralNouns[pluralNounPopup.indexOfSelectedItem]
        
        // Phrase
        let phrase = phraseTextView.string ?? ""
        
        // Date
        let dateFormatter = NSDateFormatter()
        dateFormatter.dateStyle = NSDateFormatterStyle.LongStyle
        let date = dateFormatter.stringFromDate(datePicker.dateValue)
        
        // Speak or SHOUT
        var voice = "said"
        if yellCheck.state == NSOnState {
            voice = "yelled"
        }
        
        // Create the mad lib sentence
        let results = "On \(date), at \(placeString) a \(singularNoun) \(pastTenseVerb) \(amount) \(pluralNoun) and \(voice), \(phrase)!"
        
        // Display the mad lib sentence
        resultTextField.stringValue = results
        
        // Load the rage face image
        imageView.image = NSImage(named: "face.png")

    }
    
    
}
